@@ -41,15 +41,20 @@
 #'
 resample_cifti_wrapper <- function(
   original_fnames, resamp_fnames=NULL,
-  original_res, resamp_res,
+  original_res,
+  resamp_res, resamp_method=c("barycentric", "adaptive"),
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
   surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
   read_dir=NULL, write_dir=NULL) {
 
   # Get kwargs.
   resamp_kwargs <- list(
-    original_res=original_res, resamp_res=resamp_res,
-    surfL_original_fname=surfL_original_fname, 
+    original_res=original_res,
+    resamp_res=resamp_res, resamp_method=resamp_method,
+    areaL_original_fname=areaL_original_fname,
+    areaR_original_fname=areaR_original_fname,
+    surfL_original_fname=surfL_original_fname,
     surfR_original_fname=surfR_original_fname,
     surfL_target_fname=surfL_target_fname,
     surfR_target_fname=surfR_target_fname,
@@ -105,6 +110,8 @@ resample_cifti_wrapper <- function(
 #'  If \code{NULL} (default), will use default names created by
 #'  \code{\link{resample_cifti_default_fname}}.
 #' @inheritParams resamp_res_Param_required
+#' @inheritParams resamp_method_Param
+#' @inheritParams resamp_area_Param
 #' @param write_dir Where to write the resampled CIFTI (and surfaces if present.)
 #'  If \code{NULL} (default), will use the current working directory if \code{x}
 #'  was a CIFTI file, and a temporary directory if \code{x} was a \code{"xifti"}
@@ -133,7 +140,9 @@ resample_cifti <- function(
   x=NULL, cifti_target_fname=NULL,
   surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
-  resamp_res, write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
+  resamp_res, resamp_method=c("barycentric", "adaptive"),
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
+  write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
 
   # Handle if no data ----------------------------------------------------------
   if (is.null(x)) {
@@ -282,9 +291,12 @@ resample_cifti <- function(
 
   # Do resample_cifti_components.
   resamp_result <- resample_cifti_wrapper(
-    original_res=original_res, resamp_res=resamp_res,
+    original_res=original_res,
+    resamp_res=resamp_res, resamp_method=resamp_method,
+    areaL_original_fname=areaL_original_fname,
+    areaR_original_fname=areaR_original_fname,
     original_fnames=to_resample, resamp_fnames=NULL,
-    surfL_original_fname=surfL_original_fname, 
+    surfL_original_fname=surfL_original_fname,
     surfR_original_fname=surfR_original_fname,
     surfL_target_fname=surfL_target_fname,
     surfR_target_fname=surfR_target_fname,
@@ -347,13 +359,17 @@ resampleCIfTI <- function(
   x=NULL, cifti_target_fname=NULL,
   surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
-  resamp_res, write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
+  resamp_res, resamp_method=c("barycentric", "adaptive"),
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
+  write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
 
   resample_cifti(
     x=x, cifti_target_fname=cifti_target_fname,
     surfL_original_fname=surfL_original_fname, surfR_original_fname=surfR_original_fname,
     surfL_target_fname=surfL_target_fname, surfR_target_fname=surfR_target_fname,
-    resamp_res=resamp_res, write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
+    resamp_res=resamp_res, resamp_method=resamp_method,
+    areaL_original_fname=areaL_original_fname, areaR_original_fname=areaR_original_fname,
+    write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
   )
 }
 
@@ -363,13 +379,17 @@ resamplecii <- function(
   x=NULL, cifti_target_fname=NULL,
   surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
-  resamp_res, write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
+  resamp_res, resamp_method=c("barycentric", "adaptive"),
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
+  write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
 
   resample_cifti(
     x=x, cifti_target_fname=cifti_target_fname,
     surfL_original_fname=surfL_original_fname, surfR_original_fname=surfR_original_fname,
     surfL_target_fname=surfL_target_fname, surfR_target_fname=surfR_target_fname,
-    resamp_res=resamp_res, write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
+    resamp_res=resamp_res, resamp_method=resamp_method,
+    areaL_original_fname=areaL_original_fname, areaR_original_fname=areaR_original_fname,
+    write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
   )
 }
 
@@ -379,12 +399,16 @@ resample_xifti <- function(
   x=NULL, cifti_target_fname=NULL,
   surfL_original_fname=NULL, surfR_original_fname=NULL,
   surfL_target_fname=NULL, surfR_target_fname=NULL,
-  resamp_res, write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
+  resamp_res, resamp_method=c("barycentric", "adaptive"),
+  areaL_original_fname=NULL, areaR_original_fname=NULL,
+  write_dir=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
 
   resample_cifti(
     x=x, cifti_target_fname=cifti_target_fname,
     surfL_original_fname=surfL_original_fname, surfR_original_fname=surfR_original_fname,
     surfL_target_fname=surfL_target_fname, surfR_target_fname=surfR_target_fname,
-    resamp_res=resamp_res, write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
+    resamp_res=resamp_res, resamp_method=resamp_method,
+    areaL_original_fname=areaL_original_fname, areaR_original_fname=areaR_original_fname,
+    write_dir=write_dir, mwall_values=mwall_values, verbose=verbose
   )
 }
