@@ -50,7 +50,7 @@ smooth_cifti <- function(
 
   # Args check -----------------------------------------------------------------
   input_is_xifti <- is.xifti(x, messages=FALSE)
-  surfL_return <- surfR_return <- FALSE
+  surfL_delete <- surfR_delete <- FALSE
 
   # Setup ----------------------------------------------------------------------
   if (input_is_xifti) {
@@ -83,12 +83,12 @@ smooth_cifti <- function(
 
     # Get the surfaces present.
     if (is.null(surfL_fname) && !is.null(x$surf$cortex_left)) {
-      surfL_return <- TRUE
+      surfL_delete <- TRUE
       surfL_fname <- file.path(tempdir(), "left.surf.gii")
       write_surf_gifti(x$surf$cortex_left, surfL_fname, hemisphere="left")
     }
     if (is.null(surfR_fname) && !is.null(x$surf$cortex_right)) {
-      surfR_return <- TRUE
+      surfR_delete <- TRUE
       surfR_fname <- file.path(tempdir(), "right.surf.gii")
       write_surf_gifti(x$surf$cortex_right, surfR_fname, hemisphere="right")
     }
@@ -251,8 +251,8 @@ smooth_cifti <- function(
       cifti_fname = cifti_target_fname, 
       brainstructures = brainstructures
     )
-    if (surfL_return) { read_xifti_args$surfL_fname <- surfL_fname }
-    if (surfR_return) { read_xifti_args$surfR_fname <- surfR_fname }
+    if (surfL_delete) { file.remove(surfL_fname) }
+    if (surfR_delete) { file.remove(surfR_fname) }
     return(do.call(read_xifti, read_xifti_args))
   } else {
     return(invisible(cifti_target_fname))
