@@ -2,32 +2,32 @@
 #'
 #' "ROY_BIG_BL", the default palette from the Connectome Workbench.
 #'
-#' Yields the landmark color hex codes and values for the "ROY_BIG_BL" palette. 
-#'  This is the same color palette as the default Connectome Workbench palette. 
+#' Yields the landmark color hex codes and values for the "ROY_BIG_BL" palette.
+#'  This is the same color palette as the default Connectome Workbench palette.
 #'  Source: https://github.com/Washington-University/workbench/blob/master/src/Files/PaletteFile.cxx
 #'
-#' @param min The minimum value for the color mapping. As in the original 
+#' @param min The minimum value for the color mapping. As in the original
 #'  palette, the last color (aqua) is actually placed at the bottom .5\% between
 #'  the minimum and maximum. Default: \code{0}
-#' @param max The maximum value for the color mapping. If this value is lower 
-#'  than the minimum, the color mapping will be reversed. If this is equal to 
+#' @param max The maximum value for the color mapping. If this value is lower
+#'  than the minimum, the color mapping will be reversed. If this is equal to
 #'  the minimum, a palette with only the color black will be returned.
 #'  Default: \code{1}.
-#' @param mid (Optional) The midpoint value for the color mapping. If 
+#' @param mid (Optional) The midpoint value for the color mapping. If
 #'  \code{NULL} (default), the true midpoint is used.
 #' @param half \code{"positive"} or \code{"negative"} to use the positive half
 #'  (black --> red --> yellow) or negative half (black --> blue --> purple -->
-#'  green --> aqua) only. \code{NULL} (default) or \code{FALSE} to use entire 
+#'  green --> aqua) only. \code{NULL} (default) or \code{FALSE} to use entire
 #'  palette.
 #' @param pos_half Deprecated. Use \code{half}.
 #'
-#' @return A data.frame with two columns: \code{"color"} (character: color hex 
+#' @return A data.frame with two columns: \code{"color"} (character: color hex
 #'  codes) and \code{"value"} (numeric)
-#' 
+#'
 #' @importFrom grDevices col2rgb
 #'
-#' @export 
-#' 
+#' @export
+#'
 ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
   stopifnot(length(min)==1)
   stopifnot(length(max)==1)
@@ -48,7 +48,7 @@ ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
   }
   if (is.null(half) || identical(half, FALSE)) {
     half <- "no"
-  } 
+  }
   half <- match.arg(half, c("no", "positive", "negative"))
 
   # Use the same landmark color RGB values, and same spacing. Note the spacing
@@ -59,20 +59,20 @@ ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
   #     is no visual difference.
   color <- c(
     "#ffff00", "#fff400", "#ffc800",
-    "#ff7800", "#ff0000", "#c80000", 
-    "#960000", "#640000", "#3c0000", 
-    "#000000", 
+    "#ff7800", "#ff0000", "#c80000",
+    "#960000", "#640000", "#3c0000",
+    "#000000",
     "#000050", "#0000aa", "#4b007d",
-    "#7d00a0", "#4b7d00", "#00c800", 
+    "#7d00a0", "#4b7d00", "#00c800",
     "#00ff00", "#00ffff", "#00ffff"
   )
   value <- c(
-    1.000,  0.975,  0.875, 
-    0.750,  0.625,  0.500, 
-    0.375,  0.250,  0.125, 
-    0.000, 
+    1.000,  0.975,  0.875,
+    0.750,  0.625,  0.500,
+    0.375,  0.250,  0.125,
+    0.000,
     -0.125, -0.250, -0.375,
-    -0.500, -0.625, -0.750, 
+    -0.500, -0.625, -0.750,
     -0.875, -0.990, -1.000
   )
 
@@ -89,7 +89,7 @@ ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
     # Normalize the values to [min, max].
     value <- (value + 1) * (max - min) + min
   } else {
-    # Normalize the values to [min, max]. 
+    # Normalize the values to [min, max].
     # Note that the bottom 0.5% are all #00ffff.
     value <- (value + 1)/2
     value <- value * (max - min) + min
@@ -109,36 +109,36 @@ ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
 }
 
 #' Make a color palette.
-#' 
-#' Control the mapping of values to colors with \code{colors}, 
+#'
+#' Control the mapping of values to colors with \code{colors},
 #'  \code{color_mode}, and \code{zlim}.
 #'
-#' There are three kinds of arguments for \code{colors}: \code{"ROY_BIG_BL"}, 
-#'  the name of a ColorBrewer palette (see \code{RColorBrewer::brewer.pal.info} 
-#'  and colorbrewer2.org), the name of a viridisLite palette, or a character 
+#' There are three kinds of arguments for \code{colors}: \code{"ROY_BIG_BL"},
+#'  the name of a ColorBrewer palette (see \code{RColorBrewer::brewer.pal.info}
+#'  and colorbrewer2.org), the name of a viridisLite palette, or a character
 #'  vector of color names.
 #'
 #' If \code{colors=="ROY_BIG_BL"}, the "ROY_BIG_BL" palette will be used. It is
-#'  the same palette as the default for the Connectome Workbench application 
-#'  (https://github.com/Washington-University/workbench/blob/master/src/Files/PaletteFile.cxx). 
-#'  The midpoint will be colored 
-#'  black. From the midpoint toward the upper bound, colors will proceed from 
-#'  black to red to yellow. From the midpoint toward the lower bound, colors 
+#'  the same palette as the default for the Connectome Workbench application
+#'  (https://github.com/Washington-University/workbench/blob/master/src/Files/PaletteFile.cxx).
+#'  The midpoint will be colored
+#'  black. From the midpoint toward the upper bound, colors will proceed from
+#'  black to red to yellow. From the midpoint toward the lower bound, colors
 #'  will proceed from black to blue to purple to green to aqua. Here is how each
 #'  color mode behaves if \code{colors=="ROY_BIG_BL"}:
 #'
 #' \describe{
-#'  \item{\code{color_mode=="sequential"}}{Only half of the palette will be 
+#'  \item{\code{color_mode=="sequential"}}{Only half of the palette will be
 #'    used. If \code{zlim} is length 2, the higher value will be the maximum and
 #'    the lower value will be the minimum. Set \code{zlim[1] > zlim[2]} to
-#'    reverse the color scale. (Note that the second half, black --> red --> 
-#'    yellow, is used by default. To use the negative half specify 
+#'    reverse the color scale. (Note that the second half, black --> red -->
+#'    yellow, is used by default. To use the negative half specify
 #'    \code{colors=="ROY_BIG_BL_neg"} instead. It will also be used automatically
-#'    by \code{xifti_read_surface} when the data range is negative.) 
+#'    by \code{xifti_read_surface} when the data range is negative.)
 #'    \code{zlim} can also be length 10, in which case each value corresponds to
 #'    the position of an individual color in the half palette.
 #'  }
-#'  \item{\code{color_mode=="qualitative"}}{"ROY_BIG_BL" is not recommended for 
+#'  \item{\code{color_mode=="qualitative"}}{"ROY_BIG_BL" is not recommended for
 #'    qualitative data, so a warning will be issued. Palette colors will be
 #'    selected from the landmark "ROY_BIG_BL" colors, with interpolated colors
 #'    added if the number of colors in the palette (18) is less than this range.
@@ -155,56 +155,56 @@ ROY_BIG_BL <- function(min=0, max=1, mid=NULL, half=NULL, pos_half=FALSE) {
 #'  }
 #' }
 #'
-#' If \code{colors} is the name of an RColorBrewer palette (see 
-#'  \code{RColorBrewer::brewer.pal.info}) or viridisLite palette, the colors in 
-#'  that palette will be used, and the following behavior applies. 
+#' If \code{colors} is the name of an RColorBrewer palette (see
+#'  \code{RColorBrewer::brewer.pal.info}) or viridisLite palette, the colors in
+#'  that palette will be used, and the following behavior applies.
 #'  If \code{colors} is a character vector of color names (hex codes or standard
 #'  R color names), the following behavior applies directly:
 #'
 #' \describe{
-#'  \item{\code{color_mode=="sequential"}}{If \code{zlim} is length 2, the 
+#'  \item{\code{color_mode=="sequential"}}{If \code{zlim} is length 2, the
 #'    higher value will be the maximum and the lower value will be the minimum.
-#'    Set \code{zlim[1] > zlim[2]} to reverse the color scale. \code{zlim} can 
-#'    also be the same length as the palette, in which case each value 
+#'    Set \code{zlim[1] > zlim[2]} to reverse the color scale. \code{zlim} can
+#'    also be the same length as the palette, in which case each value
 #'    corresponds to the position of an individual color in the palette.
 #'  }
-#'  \item{\code{color_mode=="qualitative"}}{\code{zlim} should be a single 
-#'    number: the number of unique colors to get. Color interpolation will be 
-#'    used if the number of colors in the palette is less than this range. If 
-#'    \code{length(zlim)==length(colors)}, each color will be mapped to each 
+#'  \item{\code{color_mode=="qualitative"}}{\code{zlim} should be a single
+#'    number: the number of unique colors to get. Color interpolation will be
+#'    used if the number of colors in the palette is less than this range. If
+#'    \code{length(zlim)==length(colors)}, each color will be mapped to each
 #'     corresponding value.
 #'  }
 #'  \item{\code{color_mode=="diverging"}}{If \code{zlim} is length 2 or 3, the
 #'    lowest number will be the lower bound and the highest number will
 #'    be the upper bound. If \code{zlim} is length 3, the middle number will be the
 #'    midpoint. Set \code{zlim} in descending order to reverse the color scale.
-#'    \code{zlim} can also be the same length as the palette, in which case each 
+#'    \code{zlim} can also be the same length as the palette, in which case each
 #'    value corresponds to the position of an individual color in the palette.
 #'  }
 #' }
 #'
-#' @param colors (Optional) "ROY_BIG_BL", the name of a ColorBrewer palette 
+#' @param colors (Optional) "ROY_BIG_BL", the name of a ColorBrewer palette
 #'  (see \code{RColorBrewer::brewer.pal.info} and colorbrewer2.org), the name of
-#'  a viridisLite palette, or a character vector of colors. 
-#'  \code{NULL} (default) will use \code{"ROY_BIG_BL"} 
-#'  if \code{color_mode} is \code{"sequential"} or \code{"diverging"}, and 
-#'  \code{"Set2"} if \code{color_mode} is \code{"qualitative"}. See the 
+#'  a viridisLite palette, or a character vector of colors.
+#'  \code{NULL} (default) will use \code{"ROY_BIG_BL"}
+#'  if \code{color_mode} is \code{"sequential"} or \code{"diverging"}, and
+#'  \code{"Set2"} if \code{color_mode} is \code{"qualitative"}. See the
 #'  description for more details.
-#' @param color_mode (Optional) \code{"sequential"}, \code{"qualitative"}, or 
-#'  \code{"diverging"}. Default: \code{"sequential"}. See the description for 
+#' @param color_mode (Optional) \code{"sequential"}, \code{"qualitative"}, or
+#'  \code{"diverging"}. Default: \code{"sequential"}. See the description for
 #'  more details.
-#' @param zlim (Optional) Controls the mapping of values to each color in 
+#' @param zlim (Optional) Controls the mapping of values to each color in
 #'  \code{colors}. See the description for more details.
 #'
-#' @return A data.frame with two columns: \code{"color"} (character: color hex 
+#' @return A data.frame with two columns: \code{"color"} (character: color hex
 #'  codes) and \code{"value"} (numeric)
-#' 
+#'
 #' @importFrom grDevices colorRampPalette
 #' @importFrom RColorBrewer brewer.pal.info brewer.pal
 #' @import viridisLite
 #'
 #' @export
-#' 
+#'
 make_color_pal <- function(
   colors=NULL, color_mode=c("sequential", "qualitative", "diverging"), zlim=NULL) {
 
@@ -233,7 +233,7 @@ make_color_pal <- function(
   }
 
   if (color_mode == "qualitative") {
-    if (length(zlim) != 1) { 
+    if (length(zlim) != 1) {
       warning("The number of colors will be the first element in `zlim`.\n")
       zlim <- zlim[1]
     }
@@ -299,30 +299,37 @@ make_color_pal <- function(
   # ----------------------------------------------------------------------------
   # RColorBrewer / Individual colors -------------------------------------------
   # ----------------------------------------------------------------------------
- 
+
   # RColor Brewer --> Individual colors
   was_viridis <- FALSE
+  viridis_cols <- c(
+    "viridis", "magma", "plasma",
+    "inferno", "cividis", "mako",
+    "rocket", "turbo"
+  )
   if ((N_COLORS_PRE == 1) && (colors %in% row.names(brewer.pal.info))) {
     colors_info <- brewer.pal.info[row.names(brewer.pal.info) == colors,]
     brewer_mode <- match.arg(
-      as.character(colors_info$category), 
+      as.character(colors_info$category),
       c("sequential", "qualitative", "diverging")
     )
     if (brewer_mode != color_mode) {
       warning(paste0(
-        "The RColorBrewer palette type is ", brewer_mode, 
+        "The RColorBrewer palette type is ", brewer_mode,
         " but the color_mode is ", color_mode, ".\n"
       ))
     }
     colors <- brewer.pal(as.numeric(colors_info$maxcolors), colors)
   # viridis --> Individual colors
-  } else if ((N_COLORS_PRE == 1) && (colors %in% c("cividis", "inferno", "magma", "plasma", "viridis"))) {
+  } else if ((N_COLORS_PRE == 1) && (colors %in% viridis_cols)) {
     was_viridis <- TRUE
-    vir_opt <- switch(colors, 
-      magma = "A", inferno = "B", plasma = "C", viridis = "D", cividis = "E"
+    vir_opt <- switch(colors,
+      magma = "A", inferno = "B", plasma = "C", viridis = "D", cividis = "E",
+      rocket = "F", mako = "G", turbo="H"
     )
     colors <- viridisLite::viridis.map[viridisLite::viridis.map$opt==vir_opt,seq(3)]
     colors <- apply(colors, 1, function(x){rgb(red=x[1], green=x[2], blue=x[3])})
+    names(colors) <- NULL
   }
 
   # Get `values` for sequential.
@@ -400,20 +407,20 @@ make_color_pal <- function(
   pal
 }
 
-#' Interpolates between entries in the input palette to make a larger palette 
+#' Interpolates between entries in the input palette to make a larger palette
 #'  with COLOR_RES entries.
 #'
-#' @param pal The color palette to expand, as a data.frame with two columns: 
+#' @param pal The color palette to expand, as a data.frame with two columns:
 #'  \code{"color"} (character: color hex codes) and \code{"value"} (numeric).
-#' @param COLOR_RES The number of entries to have in the output palette. 
+#' @param COLOR_RES The number of entries to have in the output palette.
 #'
-#' @return A data.frame with two columns: \code{"color"} (character: color hex 
+#' @return A data.frame with two columns: \code{"color"} (character: color hex
 #'  codes) and \code{"value"} (numeric)
 #'
-#' @importFrom grDevices colorRampPalette 
+#' @importFrom grDevices colorRampPalette
 #'
 #' @export
-#' 
+#'
 expand_color_pal <- function(pal, COLOR_RES=255) {
   if (nrow(pal) >= COLOR_RES) { return(pal) }
 
@@ -423,7 +430,7 @@ expand_color_pal <- function(pal, COLOR_RES=255) {
     cols <- as.character( rep(pal$color[1], COLOR_RES) )
   } else {
     colors <- as.character(pal$color)
-    # Interpolate between palette values to obtain at least COLOR_RES 
+    # Interpolate between palette values to obtain at least COLOR_RES
     #   colors levels.
     color_res <- COLOR_RES * diff(pal$value)/diff(range(pal$value))
     color_res <- as.integer(round(pmax(color_res, 2)))
@@ -437,7 +444,7 @@ expand_color_pal <- function(pal, COLOR_RES=255) {
 
     vals <- vector(length=0, mode="numeric")
     cols <- vector(length=0, mode="character")
-    
+
     for(ii in 1:(nrow(pal)-1)) {
       next_vals <- seq(pal$value[ii], pal$value[ii+1], length.out=color_res[ii]+1)
       next_vals <- next_vals[seq(length(next_vals)-1)]
@@ -456,20 +463,20 @@ expand_color_pal <- function(pal, COLOR_RES=255) {
 }
 
 #' Use a color palette
-#' 
+#'
 #' Applies a palette to a data vector to yield a vector of colors.
 #'
 #' @param data_values The values to map to colors
 #' @param pal The palette to use to map values to colors
 #' @param color_NA The color to use for \code{NA} values. Default: \code{"white"}.
-#' @param indices Return the numeric indices of colors in \code{pal$value} 
+#' @param indices Return the numeric indices of colors in \code{pal$value}
 #'  rather than the colors themselves. A value of \code{0} will be used for
 #'  missing data. Default: \code{FALSE}.
-#' 
+#'
 #' @return A character vector of color names (or integers if \code{indices}).
-#' 
+#'
 #' @export
-#' 
+#'
 use_color_pal <- function(data_values, pal, color_NA="white", indices=FALSE) {
 
   stopifnot(is.character(color_NA) && length(color_NA==1))
@@ -487,9 +494,9 @@ use_color_pal <- function(data_values, pal, color_NA="white", indices=FALSE) {
     out[!mask] <- apply(outer(as.numeric(data_values[!mask]), pal$cut, '>='), 1, sum)
   }
 
-  if (!indices) { 
+  if (!indices) {
     out <- c(color_NA, as.character(pal$color))[out + 1]
   }
 
   out
-}
\ No newline at end of file
+}
